@@ -8,7 +8,7 @@ __all__ = ['load_codes', 'language_codes']
 
 def load_codes(file):
     '''
-    Opens up file located under the etc directory conaining language
+    Opens up file located under the etc directory containing language
     codes and prints them out
     '''
     filepath = abspath(join(dirname(__file__), 'etc', file))
@@ -18,8 +18,24 @@ def load_codes(file):
 
 def language_codes(lang):
     '''
-    Prints out the language codes available.
+    Returns a dict corresponding to the language codes available for source lang
     '''
+    table = {}
     codes = load_codes('supported_translations.json')[lang]
     for code in codes:
-        print(code['name'].ljust(23), '\t', code['language'].ljust(5))
+        table[code['language']] = code['name']
+    return table
+
+def print_table(lang):
+    '''
+    Generates a formatted table of language codes
+    '''
+    table = {}
+    codes = load_codes('supported_translations.json')[lang]
+    for code in codes:
+        print(
+            '{language:<8} {name:\u3000<20}'.format(
+                name=code['name'],
+                language=code['language'])
+        )
+    return
